@@ -241,7 +241,23 @@ class LambdaToElasticSearchAndKibana(
         :summary: Constructs a new instance of the LambdaToElasticSearchAndKibana class.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(LambdaToElasticSearchAndKibana.__init__)
+            def stub(
+                scope: constructs.Construct,
+                id: builtins.str,
+                *,
+                domain_name: builtins.str,
+                cognito_domain_name: typing.Optional[builtins.str] = None,
+                create_cloud_watch_alarms: typing.Optional[builtins.bool] = None,
+                deploy_vpc: typing.Optional[builtins.bool] = None,
+                domain_endpoint_environment_variable_name: typing.Optional[builtins.str] = None,
+                es_domain_props: typing.Optional[typing.Union[aws_cdk.aws_elasticsearch.CfnDomainProps, typing.Dict[str, typing.Any]]] = None,
+                existing_lambda_obj: typing.Optional[aws_cdk.aws_lambda.Function] = None,
+                existing_vpc: typing.Optional[aws_cdk.aws_ec2.IVpc] = None,
+                lambda_function_props: typing.Optional[typing.Union[aws_cdk.aws_lambda.FunctionProps, typing.Dict[str, typing.Any]]] = None,
+                vpc_props: typing.Optional[typing.Union[aws_cdk.aws_ec2.VpcProps, typing.Dict[str, typing.Any]]] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = LambdaToElasticSearchAndKibanaProps(
@@ -354,7 +370,21 @@ class LambdaToElasticSearchAndKibanaProps:
         if isinstance(vpc_props, dict):
             vpc_props = aws_cdk.aws_ec2.VpcProps(**vpc_props)
         if __debug__:
-            type_hints = typing.get_type_hints(LambdaToElasticSearchAndKibanaProps.__init__)
+            def stub(
+                *,
+                domain_name: builtins.str,
+                cognito_domain_name: typing.Optional[builtins.str] = None,
+                create_cloud_watch_alarms: typing.Optional[builtins.bool] = None,
+                deploy_vpc: typing.Optional[builtins.bool] = None,
+                domain_endpoint_environment_variable_name: typing.Optional[builtins.str] = None,
+                es_domain_props: typing.Optional[typing.Union[aws_cdk.aws_elasticsearch.CfnDomainProps, typing.Dict[str, typing.Any]]] = None,
+                existing_lambda_obj: typing.Optional[aws_cdk.aws_lambda.Function] = None,
+                existing_vpc: typing.Optional[aws_cdk.aws_ec2.IVpc] = None,
+                lambda_function_props: typing.Optional[typing.Union[aws_cdk.aws_lambda.FunctionProps, typing.Dict[str, typing.Any]]] = None,
+                vpc_props: typing.Optional[typing.Union[aws_cdk.aws_ec2.VpcProps, typing.Dict[str, typing.Any]]] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument domain_name", value=domain_name, expected_type=type_hints["domain_name"])
             check_type(argname="argument cognito_domain_name", value=cognito_domain_name, expected_type=type_hints["cognito_domain_name"])
             check_type(argname="argument create_cloud_watch_alarms", value=create_cloud_watch_alarms, expected_type=type_hints["create_cloud_watch_alarms"])
